% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cytof_cluster.R
\name{cytof_cluster}
\alias{cytof_cluster}
\title{Subset detection by clustering}
\usage{
cytof_cluster(ydata = NULL, xdata = NULL, method = c("Rphenograph",
  "ClusterX", "DensVM", "FlowSOM", "NULL"), FlowSOM_k = 40)
}
\arguments{
\item{ydata}{A matrix of the dimension reduced data.}

\item{xdata}{A matrix of the expression data.}

\item{method}{Cluster method including \code{DensVM}, \code{densityClustX}, \code{Rphenograph} and \code{FlowSOM}.}

\item{FlowSOM_k}{Number of clusters for meta clustering in FlowSOM.}
}
\value{
a vector of the clusters assigned for each row of the ydata
}
\description{
Apply clustering algorithms to detect cell subsets. \code{DensVM} and \code{ClusterX} 
clustering is based on the transformend ydata and use xdata to train the model. 
While \code{Rphenograph} directly works on the high dimemnional xdata. \code{FlowSOM} is 
integrated from FlowSOM pacakge (https://bioconductor.org/packages/release/bioc/html/FlowSOM.html).
}
\examples{
d<-system.file('extdata', package='cytofkit')
fcsFile <- list.files(d, pattern='.fcs$', full=TRUE)
parameters <- list.files(d, pattern='.txt$', full=TRUE)
markers <- as.character(read.table(parameters, sep = "\\t", header = TRUE)[, 1])
xdata <- cytof_exprsMerge(fcsFile, markers = markers, mergeMethod = 'fixed', fixedNum = 100)
ydata <- cytof_dimReduction(xdata, method = "tsne")
clusters <- cytof_cluster(ydata, xdata, method = "ClusterX")
}
